summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorseungha.son <seungha.son@samsung.com>2017-01-17 11:23:34 +0900
committerSon seungha <seungha.son@samsung.com>2017-01-17 02:15:11 -0800
commita5558e2f17ae3e49445a4e7b80710aa2a57b3ba5 (patch)
treebbca96f37d8bd9ed06004b761a6640a7203cd916
parent8c5d23815751f9b0c101fd89235f89f141ca8e2f (diff)
downloadnotification-accepted/tizen/3.0/mobile/20170118.043448.tar.gz
notification-accepted/tizen/3.0/mobile/20170118.043448.tar.bz2
notification-accepted/tizen/3.0/mobile/20170118.043448.zip
- Get/Set timeout value in second when the notification can be hidden from the viewer. Signed-off-by: seungha.son <seungha.son@samsung.com> Change-Id: I2a013f58da6aa16bf153e2ca6eb5641a661e92c5
-rw-r--r--include/notification_internal.h75
-rw-r--r--include/notification_private.h6
-rw-r--r--scripts/505.notification_upgrade.sh10
-rwxr-xr-xsrc/notification.c6
-rwxr-xr-xsrc/notification_db.c6
-rwxr-xr-xsrc/notification_internal.c24
-rwxr-xr-xsrc/notification_ipc.c6
-rwxr-xr-xsrc/notification_noti.c44
8 files changed, 147 insertions, 30 deletions
diff --git a/include/notification_private.h b/include/notification_private.h
index 06eca17..174c788 100644
--- a/include/notification_private.h
+++ b/include/notification_private.h
@@ -94,7 +94,8 @@ struct _notification {
int ongoing_duration; /* Ongoing duration time */
bool auto_remove;
notification_button_index_e default_button_index;
- int timeout;
+ int hide_timeout; /* Time for hide in banner */
+ int delete_timeout; /* Time for delete in view notification */
int text_input_max_length;
bool event_flag;
bool is_translation;
@@ -156,7 +157,8 @@ typedef enum notification_data_type {
NOTIFICATION_DATA_TYPE_ONGOING_DURATION,
NOTIFICATION_DATA_TYPE_AUTO_REMOVE,
NOTIFICATION_DATA_TYPE_DEFAULT_BUTTON,
- NOTIFICATION_DATA_TYPE_TIMEOUT,
+ NOTIFICATION_DATA_TYPE_HIDE_TIMEOUT,
+ NOTIFICATION_DATA_TYPE_DELETE_TIMEOUT,
NOTIFICATION_DATA_TYPE_TEXT_INPUT_MAX_LENGTH,
NOTIFICATION_DATA_TYPE_EVENT_FLAG,
NOTIFICATION_DATA_TYPE_TRANSLATION,
diff --git a/scripts/505.notification_upgrade.sh b/scripts/505.notification_upgrade.sh
index f57d2ff..152e55a 100644
--- a/scripts/505.notification_upgrade.sh
+++ b/scripts/505.notification_upgrade.sh
@@ -61,6 +61,11 @@ CREATE TABLE noti_list_temp (
progress_percentage DOUBLE default 0,
ongoing_flag INTEGER default 0,
auto_remove INTEGER default 1,
+ default_button_index INTEGER default 0,
+ hide_timeout INTEGER default 0,
+ delete_timeout INTEGER default 0,
+ text_input_max_length INTEGER default 0,
+ event_flag INTEGER default 0,
uid INTEGER
);
INSERT INTO noti_list_temp (type, layout, caller_pkgname, launch_pkgname, image_path, group_id, internal_group_id, priv_id, title_key, b_text, b_key, tag, b_format_args, num_format_args, text_domain, text_dir, time, insert_time, args, group_args, b_execute_option, b_service_responding, b_service_single_launch, b_service_multi_launch, b_event_handler_click_on_button_1, b_event_handler_click_on_button_2, b_event_handler_click_on_button_3, b_event_handler_click_on_button_4, b_event_handler_click_on_button_5, b_event_handler_click_on_button_6, b_event_handler_click_on_icon, b_event_handler_click_on_thumbnail, sound_type, sound_path, vibration_type, vibration_path, led_operation, led_argb, led_on_ms, led_off_ms, flags_for_property, flag_simmode, display_applist, progress_size, progress_percentage, ongoing_flag, auto_remove) \
@@ -153,6 +158,11 @@ CREATE TABLE noti_template (
progress_percentage DOUBLE default 0,
ongoing_flag INTEGER default 0,
auto_remove INTEGER default 1,
+ default_button_index INTEGER default 0,
+ hide_timeout INTEGER default 0,
+ delete_timeout INTEGER default 0,
+ text_input_max_length INTEGER default 0,
+ event_flag INTEGER default 0,
uid INTEGER,
template_name TEXT,
UNIQUE (caller_pkgname, template_name)
diff --git a/src/notification.c b/src/notification.c
index d3a7735..f53a67d 100755
--- a/src/notification.c
+++ b/src/notification.c
@@ -1437,7 +1437,8 @@ static notification_h _notification_create(notification_type_e type)
noti->ongoing_flag = false;
noti->default_button_index = 0;
noti->ongoing_value_type = NOTIFICATION_ONGOING_VALUE_TYPE_PERCENT;
- noti->timeout = 0;
+ noti->hide_timeout = 0;
+ noti->delete_timeout = 0;
noti->event_flag = false;
noti->is_translation = false;
@@ -1648,7 +1649,8 @@ EXPORT_API int notification_clone(notification_h noti, notification_h *clone)
new_noti->ongoing_duration = noti->ongoing_duration;
new_noti->auto_remove = noti->auto_remove;
new_noti->default_button_index = noti->default_button_index;
- new_noti->timeout = noti->timeout;
+ new_noti->hide_timeout = noti->hide_timeout;
+ new_noti->delete_timeout = noti->delete_timeout;
new_noti->text_input_max_length = noti->text_input_max_length;
new_noti->event_flag = noti->event_flag;
new_noti->uid = noti->uid;
diff --git a/src/notification_db.c b/src/notification_db.c
index d9c0791..efe7d15 100755
--- a/src/notification_db.c
+++ b/src/notification_db.c
@@ -85,7 +85,8 @@ create table if not exists noti_list ( \
ongoing_duration INTEGER default 0, \
auto_remove INTEGER default 1, \
default_button_index INTEGER default 0, \
- timeout INTEGER default 0, \
+ hide_timeout INTEGER default 0, \
+ delete_timeout INTEGER default 0, \
text_input_max_length INTEGER default 0, \
event_flag INTEGER default 0, \
uid INTEGER \
@@ -210,7 +211,8 @@ create table if not exists noti_list ( \
ongoing_duration INTEGER default 0, \
auto_remove INTEGER default 1, \
default_button_index INTEGER default 0, \
- timeout INTEGER default 0, \
+ hide_timeout INTEGER default 0, \
+ delete_timeout INTEGER default 0, \
text_input_max_length INTEGER default 0, \
event_flag INTEGER default 0, \
uid INTEGER, \
diff --git a/src/notification_internal.c b/src/notification_internal.c
index 67e93ee..b61b657 100755
--- a/src/notification_internal.c
+++ b/src/notification_internal.c
@@ -1512,7 +1512,7 @@ EXPORT_API int notification_get_hide_timeout(notification_h noti, int *timeout)
if (noti == NULL || timeout == NULL)
return NOTIFICATION_ERROR_INVALID_PARAMETER;
- *timeout = noti->timeout;
+ *timeout = noti->hide_timeout;
return NOTIFICATION_ERROR_NONE;
}
@@ -1522,7 +1522,27 @@ EXPORT_API int notification_set_hide_timeout(notification_h noti, int timeout)
if (noti == NULL || timeout < 0)
return NOTIFICATION_ERROR_INVALID_PARAMETER;
- noti->timeout = timeout;
+ noti->hide_timeout = timeout;
+
+ return NOTIFICATION_ERROR_NONE;
+}
+
+EXPORT_API int notification_get_delete_timeout(notification_h noti, int *timeout)
+{
+ if (noti == NULL || timeout == NULL)
+ return NOTIFICATION_ERROR_INVALID_PARAMETER;
+
+ *timeout = noti->delete_timeout;
+
+ return NOTIFICATION_ERROR_NONE;
+}
+
+EXPORT_API int notification_set_delete_timeout(notification_h noti, int timeout)
+{
+ if (noti == NULL || timeout < 0)
+ return NOTIFICATION_ERROR_INVALID_PARAMETER;
+
+ noti->delete_timeout = timeout;
return NOTIFICATION_ERROR_NONE;
}
diff --git a/src/notification_ipc.c b/src/notification_ipc.c
index 540b3b6..4bc5363 100755
--- a/src/notification_ipc.c
+++ b/src/notification_ipc.c
@@ -1900,7 +1900,8 @@ EXPORT_API GVariant *notification_ipc_make_gvariant_from_noti(notification_h not
g_variant_builder_add(&builder, "{iv}", NOTIFICATION_DATA_TYPE_ONGOING_DURATION, g_variant_new_int32(noti->ongoing_duration));
g_variant_builder_add(&builder, "{iv}", NOTIFICATION_DATA_TYPE_AUTO_REMOVE, g_variant_new_int32(noti->auto_remove));
g_variant_builder_add(&builder, "{iv}", NOTIFICATION_DATA_TYPE_DEFAULT_BUTTON, g_variant_new_int32(noti->default_button_index));
- g_variant_builder_add(&builder, "{iv}", NOTIFICATION_DATA_TYPE_TIMEOUT, g_variant_new_int32(noti->timeout));
+ g_variant_builder_add(&builder, "{iv}", NOTIFICATION_DATA_TYPE_HIDE_TIMEOUT, g_variant_new_int32(noti->hide_timeout));
+ g_variant_builder_add(&builder, "{iv}", NOTIFICATION_DATA_TYPE_DELETE_TIMEOUT, g_variant_new_int32(noti->delete_timeout));
g_variant_builder_add(&builder, "{iv}", NOTIFICATION_DATA_TYPE_TEXT_INPUT_MAX_LENGTH, g_variant_new_int32(noti->text_input_max_length));
g_variant_builder_add(&builder, "{iv}", NOTIFICATION_DATA_TYPE_EVENT_FLAG, g_variant_new_int32(noti->event_flag));
g_variant_builder_add(&builder, "{iv}", NOTIFICATION_DATA_TYPE_TRANSLATION, g_variant_new_int32(noti->is_translation));
@@ -2056,7 +2057,8 @@ EXPORT_API int notification_ipc_make_noti_from_gvariant(notification_h noti,
_variant_dict_lookup(dict, NOTIFICATION_DATA_TYPE_ONGOING_DURATION, "i", &noti->ongoing_duration);
_variant_dict_lookup(dict, NOTIFICATION_DATA_TYPE_AUTO_REMOVE, "i", &noti->auto_remove);
_variant_dict_lookup(dict, NOTIFICATION_DATA_TYPE_DEFAULT_BUTTON, "i", &noti->default_button_index);
- _variant_dict_lookup(dict, NOTIFICATION_DATA_TYPE_TIMEOUT, "i", &noti->timeout);
+ _variant_dict_lookup(dict, NOTIFICATION_DATA_TYPE_HIDE_TIMEOUT, "i", &noti->hide_timeout);
+ _variant_dict_lookup(dict, NOTIFICATION_DATA_TYPE_DELETE_TIMEOUT, "i", &noti->delete_timeout);
_variant_dict_lookup(dict, NOTIFICATION_DATA_TYPE_TEXT_INPUT_MAX_LENGTH, "i", &noti->text_input_max_length);
_variant_dict_lookup(dict, NOTIFICATION_DATA_TYPE_EVENT_FLAG, "i", &noti->event_flag);
_variant_dict_lookup(dict, NOTIFICATION_DATA_TYPE_TRANSLATION, "i", &noti->is_translation);
diff --git a/src/notification_noti.c b/src/notification_noti.c
index 07b6b62..e2a0481 100755
--- a/src/notification_noti.c
+++ b/src/notification_noti.c
@@ -264,7 +264,8 @@ static int _insertion_query_create(notification_h noti, char **query)
"flags_for_property, flag_simmode, display_applist, "
"progress_size, progress_percentage, "
"ongoing_flag, ongoing_value_type, ongoing_current, ongoing_duration, "
- "auto_remove, default_button_index, timeout, text_input_max_length, event_flag, uid) values ("
+ "auto_remove, default_button_index, hide_timeout, delete_timeout, "
+ "text_input_max_length, event_flag, uid) values ("
"%d, "
"%d, "
"'%s', '%s', "
@@ -283,7 +284,7 @@ static int _insertion_query_create(notification_h noti, char **query)
"%d, '%s', %d, '%s', %d, %d, %d, %d,"
"%d, %d, %d, "
"$progress_size, $progress_percentage, "
- "%d, %d, %d, %d, "
+ "%d, %d, %d, %d, %d,"
"%d, %d, %d, %d, %d, %d)",
noti->type,
noti->layout,
@@ -324,7 +325,8 @@ static int _insertion_query_create(notification_h noti, char **query)
noti->ongoing_duration,
noti->auto_remove,
noti->default_button_index,
- noti->timeout,
+ noti->hide_timeout,
+ noti->delete_timeout,
noti->text_input_max_length,
noti->event_flag,
noti->uid);
@@ -465,7 +467,8 @@ static int _update_query_create(notification_h noti, char **query)
"display_applist = %d, "
"progress_size = $progress_size, progress_percentage = $progress_percentage, "
"ongoing_flag = %d, ongoing_value_type = %d, ongoing_current = %d, ongoing_duration = %d, "
- "auto_remove = %d, default_button_index = %d, timeout = %d, text_input_max_length = %d, event_flag = %d "
+ "auto_remove = %d, default_button_index = %d, hide_timeout = %d, "
+ "delete_timeout = %d, text_input_max_length = %d, event_flag = %d "
"where priv_id = %d ",
noti->type,
noti->layout,
@@ -500,8 +503,9 @@ static int _update_query_create(notification_h noti, char **query)
noti->flags_for_property, flag_simmode, noti->display_applist,
noti->ongoing_flag, noti->ongoing_value_type,
noti->ongoing_current, noti->ongoing_duration,
- noti->auto_remove, noti->default_button_index, noti->timeout,
- noti->text_input_max_length, noti->event_flag, noti->priv_id);
+ noti->auto_remove, noti->default_button_index, noti->hide_timeout,
+ noti->delete_timeout, noti->text_input_max_length, noti->event_flag,
+ noti->priv_id);
/* Free decoded data */
if (args)
@@ -601,7 +605,8 @@ static void _notification_noti_populate_from_stmt(sqlite3_stmt *stmt, notificati
noti->ongoing_duration = sqlite3_column_int(stmt, col++);
noti->auto_remove = sqlite3_column_int(stmt, col++);
noti->default_button_index = sqlite3_column_int(stmt, col++);
- noti->timeout = sqlite3_column_int(stmt, col++);
+ noti->hide_timeout = sqlite3_column_int(stmt, col++);
+ noti->delete_timeout = sqlite3_column_int(stmt, col++);
noti->text_input_max_length = sqlite3_column_int(stmt, col++);
noti->event_flag = sqlite3_column_int(stmt, col++);
noti->uid = sqlite3_column_int(stmt, col++);
@@ -1057,7 +1062,8 @@ EXPORT_API int notification_noti_get_by_priv_id(notification_h noti, char *pkgna
"b_event_handler_click_on_icon, b_event_handler_click_on_thumbnail, b_event_handler_click_on_text_input_button, "
"sound_type, sound_path, vibration_type, vibration_path, led_operation, led_argb, led_on_ms, led_off_ms, "
"flags_for_property, display_applist, progress_size, progress_percentage, ongoing_flag, ongoing_value_type, "
- "ongoing_current, ongoing_duration, auto_remove, default_button_index, timeout, text_input_max_length, event_flag, uid "
+ "ongoing_current, ongoing_duration, auto_remove, default_button_index, hide_timeout, delete_timeout, "
+ "text_input_max_length, event_flag, uid "
"from noti_list ";
if (pkgname != NULL && strlen(pkgname) != 0)
@@ -1128,7 +1134,8 @@ EXPORT_API int notification_noti_get_by_tag(notification_h noti, char *pkgname,
"b_event_handler_click_on_icon, b_event_handler_click_on_thumbnail, b_event_handler_click_on_text_input_button, "
"sound_type, sound_path, vibration_type, vibration_path, led_operation, led_argb, led_on_ms, led_off_ms, "
"flags_for_property, display_applist, progress_size, progress_percentage, ongoing_flag, ongoing_value_type, "
- "ongoing_current, ongoing_duration, auto_remove, default_button_index, timeout, text_input_max_length, event_flag "
+ "ongoing_current, ongoing_duration, auto_remove, default_button_index, hide_timeout, delete_timeout, "
+ "text_input_max_length, event_flag, uid "
"from noti_list where caller_pkgname = ? and tag = ? and uid = ?", -1, &stmt, NULL);
if (ret != SQLITE_OK) {
NOTIFICATION_ERR("Error: %s\n", sqlite3_errmsg(db));
@@ -1164,7 +1171,8 @@ EXPORT_API int notification_noti_get_by_tag(notification_h noti, char *pkgname,
"b_event_handler_click_on_icon, b_event_handler_click_on_thumbnail, b_event_handler_click_on_text_input_button, "
"sound_type, sound_path, vibration_type, vibration_path, led_operation, led_argb, led_on_ms, led_off_ms, "
"flags_for_property, display_applist, progress_size, progress_percentage, ongoing_flag, ongoing_value_type, "
- "ongoing_current, ongoing_duration, auto_remove, default_button_index, timeout, text_input_max_length, event_flag, uid "
+ "ongoing_current, ongoing_duration, auto_remove, default_button_index, hide_timeout, delete_timeout, "
+ "text_input_max_length, event_flag, uid "
"from noti_list where tag = ? and uid = ?", -1, &stmt, NULL);
if (ret != SQLITE_OK) {
NOTIFICATION_ERR("Error: %s\n", sqlite3_errmsg(db));
@@ -1624,7 +1632,8 @@ EXPORT_API int notification_noti_get_grouping_list(notification_type_e type,
"b_event_handler_click_on_icon, b_event_handler_click_on_thumbnail, b_event_handler_click_on_text_input_button, "
"sound_type, sound_path, vibration_type, vibration_path, led_operation, led_argb, led_on_ms, led_off_ms, "
"flags_for_property, display_applist, progress_size, progress_percentage, ongoing_flag, ongoing_value_type, "
- "ongoing_current, ongoing_duration, auto_remove, default_button_index, timeout, text_input_max_length, event_flag, uid "
+ "ongoing_current, ongoing_duration, auto_remove, default_button_index, hide_timeout, delete_timeout, "
+ "text_input_max_length, event_flag, uid "
"from noti_list where 1 > 0 ");
if (status == VCONFKEY_TELEPHONY_SIM_INSERTED) {
@@ -1726,7 +1735,8 @@ EXPORT_API int notification_noti_get_detail_list(const char *pkgname,
"b_event_handler_click_on_icon, b_event_handler_click_on_thumbnail, b_event_handler_click_on_text_input_button, "
"sound_type, sound_path, vibration_type, vibration_path, led_operation, led_argb, led_on_ms, led_off_ms, "
"flags_for_property, display_applist, progress_size, progress_percentage, ongoing_flag, ongoing_value_type, "
- "ongoing_current, ongoing_duration, auto_remove, default_button_index, timeout, text_input_max_length, event_flag, uid "
+ "ongoing_current, ongoing_duration, auto_remove, default_button_index, hide_timeout, delete_timeout, "
+ "text_input_max_length, event_flag, uid "
"from noti_list ");
if (priv_id == NOTIFICATION_PRIV_ID_NONE && group_id == NOTIFICATION_GROUP_ID_NONE) {
@@ -1987,7 +1997,7 @@ static int _template_query_create(notification_h noti, char *template_name, char
"sound_type, sound_path, vibration_type, vibration_path, led_operation, led_argb, led_on_ms, led_off_ms, "
"flags_for_property, flag_simmode, display_applist, progress_size, progress_percentage, "
"ongoing_flag, ongoing_value_type, ongoing_current, ongoing_duration, "
- "auto_remove, default_button_index, timeout, text_input_max_length, "
+ "auto_remove, default_button_index, hide_timeout, delete_timeout, text_input_max_length, "
"event_flag, uid, template_name) values ("
"%d, "
"%d, "
@@ -2007,7 +2017,7 @@ static int _template_query_create(notification_h noti, char *template_name, char
"%d, '%s', %d, '%s', %d, %d, %d, %d, "
"%d, %d, %d, $progress_size, $progress_percentage, "
"%d, %d, %d, %d, "
- "%d, %d, %d, %d, "
+ "%d, %d, %d, %d, %d, "
"%d, %d, '%s')",
noti->type,
noti->layout,
@@ -2048,7 +2058,8 @@ static int _template_query_create(notification_h noti, char *template_name, char
noti->ongoing_duration,
noti->auto_remove,
noti->default_button_index,
- noti->timeout,
+ noti->hide_timeout,
+ noti->delete_timeout,
noti->text_input_max_length,
noti->event_flag,
noti->uid,
@@ -2216,7 +2227,8 @@ EXPORT_API int notification_noti_get_package_template(notification_h noti, char
"b_event_handler_click_on_icon, b_event_handler_click_on_thumbnail, b_event_handler_click_on_text_input_button, "
"sound_type, sound_path, vibration_type, vibration_path, led_operation, led_argb, led_on_ms, led_off_ms, "
"flags_for_property, display_applist, progress_size, progress_percentage, ongoing_flag, ongoing_value_type, "
- "ongoing_current, ongoing_duration, auto_remove, default_button_index, timeout, text_input_max_length, event_flag, uid "
+ "ongoing_current, ongoing_duration, auto_remove, default_button_index, hide_timeout, delete_timeout, "
+ "text_input_max_length, event_flag, uid "
"from noti_template where caller_pkgname = ? and template_name = ?", -1, &stmt, NULL);
if (ret != SQLITE_OK) {
NOTIFICATION_ERR("Error: %s\n", sqlite3_errmsg(db));
diff --git a/include/notification_internal.h b/include/notification_internal.h
index bb04489..c4e62a1 100644
--- a/include/notification_internal.h
+++ b/include/notification_internal.h
@@ -972,10 +972,10 @@ int notification_get_ongoing_time(notification_h noti, int *current, int *durati
int notification_set_ongoing_time(notification_h noti, int current, int duration);
/**
* @brief Gets the time that notification is hidden.
* @since_tizen 3.0
* @param[in] noti The notification handle
- * @param[out] timeout The timeout time
+ * @param[out] timeout The timeout time(sec)
* @return #NOTIFICATION_ERROR_NONE on success,
* otherwise any other value on failure
* @retval #NOTIFICATION_ERROR_NONE Success
@@ -1007,10 +1007,10 @@ int notification_set_ongoing_time(notification_h noti, int current, int duration
int notification_get_hide_timeout(notification_h noti, int *timeout);
/**
* @brief Sets the time that notification is hidden.
* @since_tizen 3.0
* @param[in] noti The notification handle
- * @param[in] timeout The timeout time
+ * @param[in] timeout The timeout time(sec)
* @return #NOTIFICATION_ERROR_NONE on success,
* otherwise any other value on failure
* @retval #NOTIFICATION_ERROR_NONE Success
@@ -1040,6 +1040,73 @@ int notification_get_hide_timeout(notification_h noti, int *timeout);
*/
int notification_set_hide_timeout(notification_h noti, int timeout);
+/**
+ * @brief Gets timeout value in second when the notification can be deleted from the viewer.
+ * @since_tizen 3.0
+ * @param[in] noti The notification handle
+ * @param[out] timeout The timeout time(sec)
+ * @return #NOTIFICATION_ERROR_NONE on success,
+ * otherwise any other value on failure
+ * @retval #NOTIFICATION_ERROR_NONE Success
+ * @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
+ * @pre Notification handle should be created by notification_create().
+ * @par Sample code:
+ * @code
+#include <notification.h>
+...
+{
+ notification_h noti = NULL;
+ int noti_err = NOTIFICATION_ERROR_NONE;
+ int timeout;
+
+ noti = notification_create(NOTIFICATION_TYPE_NOTI);
+ if (noti == NULL) {
+ return;
+ }
+
+ noti_err = notification_get_delete_timeout(noti, &timeout)
+ if (noti_err != NOTIFICATION_ERROR_NONE) {
+ notification_free(noti);
+ return;
+ }
+}
+ * @endcode
+ */
+int notification_get_delete_timeout(notification_h noti, int *timeout);
+
+/**
+ * @brief Sets timeout value in second when the notification can be deleted from the viewer.
+ * @since_tizen 3.0
+ * @param[in] noti The notification handle
+ * @param[in] timeout The timeout time(sec)
+ * @return #NOTIFICATION_ERROR_NONE on success,
+ * otherwise any other value on failure
+ * @retval #NOTIFICATION_ERROR_NONE Success
+ * @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
+ * @pre Notification handle should be created by notification_create().
+ * @par Sample code:
+ * @code
+#include <notification.h>
+...
+{
+ notification_h noti = NULL;
+ int noti_err = NOTIFICATION_ERROR_NONE;
+
+ noti = notification_create(NOTIFICATION_TYPE_NOTI);
+ if (noti == NULL) {
+ return;
+ }
+
+ noti_err = notification_set_delete_timeout(noti, 10)
+ if (noti_err != NOTIFICATION_ERROR_NONE) {
+ notification_free(noti);
+ return;
+ }
+}
+ * @endcode
+ */
+int notification_set_delete_timeout(notification_h noti, int timeout);
+
typedef void (*event_handler_cb)(notification_h noti, int event_type, void *userdata);
/**
@@ -972,10 +972,10 @@ int notification_get_ongoing_time(notification_h noti, int *current, int *durati
int notification_set_ongoing_time(notification_h noti, int current, int duration);
/**
- * @brief Gets the time that notification is hidden.
+ * @brief Gets timeout value in second when the notification can be hidden from the viewer.
* @since_tizen 3.0
* @param[in] noti The notification handle
@@ -1007,10 +1007,10 @@ int notification_set_ongoing_time(notification_h noti, int current, int duration
int notification_get_hide_timeout(notification_h noti, int *timeout);
/**
- * @brief Sets the time that notification is hidden.
+ * @brief Sets timeout value in second when the notification can be hidden from the viewer.
* @since_tizen 3.0
* @param[in] noti The notification handle